@@ -1,6 +1,6 @@
 import json, base64, os, pickle, datetime, string, re
 
-__version__ = "0.1.6"
+__version__ = "0.1.8"
 ### from ipynb extract markdown and noted output for document organization
 
 class nbparser:
@@ -16,7 +16,7 @@ class nbparser:
         self.notebook = json.loads("\n".join(open(path).readlines()))
         self.outroot = os.path.join(output_root,"source")
         self.opath = os.path.join(self.outroot, self.folder, self.basename)
-        os.makedirs(self.opath, exist_ok = True)
+        
         self.TOC, self.source = [],[]
         self.fig, self.code = [], []
         self.table = []
@@ -109,6 +109,7 @@ class nbparser:
                     self.save_fig(self.outputpath(fname), data['data'][key])
 
     def save_fig(self, fname, base64fig):
+        os.makedirs(self.opath, exist_ok = True)
         with open(fname,"wb") as f:
             f.write(base64.b64decode(base64fig))
 
@@ -196,7 +197,7 @@ class nbparser:
         return s
     
     def source_convert(self):
-        source = [line if not line =="!TOC" else self.toc_source() for line in self.source] # Table of Contents
+        source = [line if not line =="!TOC" else self.toc_source() for line in self.source if line] # Table of Contents
         source = "\n\n".join(source)
         
         # double bracket to ref
@@ -217,10 +218,10 @@ class nbparser:
 
     def write_markdown(self):        
         source = self.source_convert()
-        
-        ### Write markdown
-        with open(self.fname,"w") as f:
-            f.write(source)
+        if source:
+            ### Write markdown
+            with open(self.fname,"w") as f:
+                f.write(source)
 
 
 def toc_source(TOC):
@@ -243,7 +244,8 @@ def daily_note(note_path, check):
         source = pickle.load(f)
     
     mod, record = modified_check(source, check)
-    write_daily(note_path, mod, record)
+    if mod:
+        write_daily(note_path, mod, record)
 
 def modified_check(source, check):
     mod = {}
@@ -299,7 +301,12 @@ rm __tmp__files
 
 cd wiki
 git add *
+if [ `git diff --cached --name-only| wc -l` -eq 0 ]
+then
+echo "nothing to commit"
+else
 git commit -m "Auto commit from nbresnote `date +%F`"
+fi
 """
 
 pushsource = """#!/bin/bash
@@ -320,8 +327,10 @@ if __name__ =="__main__":
     else:
         if sys.argv[1] =="git-pre-commit":
             targets = open("__tmp__files").readlines()
-            print(targets)
+            #print(targets) #DEBUG
         elif sys.argv[1] == "install":
+            #Installation
+            # Setting git/hooks pre-commit and pre-push
             if not os.path.exists(".git"):
                 raise OSError("Please run on the base folder of git repository.")
             if not os.path.exists(".git/hooks/pre-commit"):
@@ -331,7 +340,7 @@ if __name__ =="__main__":
                 print("Change mod of 'pre-commit' file on '.git/hooks/' into 755(rwxr-xr-x).")
                 os.chmod(".git/hooks/pre-commit", 0o755)
             else:
-                print("Warning : Already exists 'pre-commit' file on '.git/hooks/'.")
+                print("Warning : Already exists 'pre-commit' file on '.git/hooks/'. Command ignored.")
             if not os.path.exists(".git/hooks/pre-push"):
                 print("Creating 'pre-push' file on '.git/hooks/'.")
                 with open(".git/hooks/pre-push","a") as f:
@@ -339,10 +348,11 @@ if __name__ =="__main__":
                 print("Change mod of 'pre-push' file on '.git/hooks/' into 755(rwxr-xr-x).")
                 os.chmod(".git/hooks/pre-push", 0o755)
             else:
-                print("Warning : Already exists 'pre-push' file on '.git/hooks/'.")
+                print("Warning : Already exists 'pre-push' file on '.git/hooks/'. Command ignored.")
             print("Done.")
             
             exit(0)
+
         else:
             targets = sys.argv[1:]
     
@@ -355,6 +365,7 @@ if __name__ =="__main__":
             check[file] = set(map(lambda x:x[1],notebook.TOC))
     
     daily_note(daily_path, check)
+    exit(0)
     
 
     
